==> haskell-gi-0.26.4-75-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-gi
version:              0.26.4
visibility:           public
id:                   haskell-gi-0.26.4-GNZaONjjoswC50nAmJCY3
key:                  haskell-gi-0.26.4-GNZaONjjoswC50nAmJCY3
license:              LGPL-2.1-only
maintainer:           Iñaki García Etxebarria (github@the.blueleaf.cc)
author:               Will Thompson and Iñaki García Etxebarria
stability:            Experimental
homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    Generate Haskell bindings for GObject Introspection capable libraries

description:
    Generate Haskell bindings for GObject Introspection capable libraries. This includes most notably
    Gtk+, but many other libraries in the GObject ecosystem provide introspection data too.

category:             Development
abi:                  c3b7fd3e9bbc01486e4ecca79145bbf0
exposed:              True
exposed-modules:
    Data.GI.CodeGen.API Data.GI.CodeGen.Cabal
    Data.GI.CodeGen.CabalHooks Data.GI.CodeGen.Callable
    Data.GI.CodeGen.Code Data.GI.CodeGen.CodeGen Data.GI.CodeGen.Config
    Data.GI.CodeGen.Constant Data.GI.CodeGen.Conversions
    Data.GI.CodeGen.CtoHaskellMap Data.GI.CodeGen.EnumFlags
    Data.GI.CodeGen.Fixups Data.GI.CodeGen.GObject
    Data.GI.CodeGen.GType Data.GI.CodeGen.GtkDoc
    Data.GI.CodeGen.Haddock Data.GI.CodeGen.Inheritance
    Data.GI.CodeGen.LibGIRepository Data.GI.CodeGen.ModulePath
    Data.GI.CodeGen.OverloadedMethods Data.GI.CodeGen.OverloadedSignals
    Data.GI.CodeGen.Overrides Data.GI.CodeGen.PkgConfig
    Data.GI.CodeGen.ProjectInfo Data.GI.CodeGen.Properties
    Data.GI.CodeGen.Signal Data.GI.CodeGen.Struct
    Data.GI.CodeGen.SymbolNaming Data.GI.CodeGen.Transfer
    Data.GI.CodeGen.Type Data.GI.CodeGen.Util Data.GI.GIR.Alias
    Data.GI.GIR.Allocation Data.GI.GIR.Arg Data.GI.GIR.BasicTypes
    Data.GI.GIR.Callable Data.GI.GIR.Callback Data.GI.GIR.Constant
    Data.GI.GIR.Deprecation Data.GI.GIR.Documentation Data.GI.GIR.Enum
    Data.GI.GIR.Field Data.GI.GIR.Flags Data.GI.GIR.Function
    Data.GI.GIR.Interface Data.GI.GIR.Method Data.GI.GIR.Object
    Data.GI.GIR.Parser Data.GI.GIR.Property Data.GI.GIR.Repository
    Data.GI.GIR.Signal Data.GI.GIR.Struct Data.GI.GIR.Type
    Data.GI.GIR.Union Data.GI.GIR.XMLUtils

hidden-modules:       Paths_haskell_gi
import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-gi-0.26.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-gi-0.26.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi
hs-libraries:         HShaskell-gi-0.26.4-GNZaONjjoswC50nAmJCY3
extra-libraries:      girepository-1.0 glib-2.0 gobject-2.0
include-dirs:
    /usr/include/gobject-introspection-1.0 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6

depends:
    Cabal-3.6.3.0 ansi-terminal-0.11.4-EPVjDSBhsFM2RMZf92XUfK
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 directory-1.3.6.2
    filepath-1.4.2.2 haskell-gi-base-0.26.4-BFXyyduHPGW6bU8MlEazkc
    mtl-2.2.2 pretty-show-1.10-JwphvxEdk99BsHrT870tUy process-1.6.16.0
    regex-tdfa-1.3.2.2-Js34ukrBSX51v3nGkmx3s
    safe-0.3.21-CqIHKdkgiB2klcxc5dxay text-1.2.5.0 transformers-0.5.6.2
    xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83
    xml-conduit-1.9.1.3-4roM0o1CnX5F2eJmoxACli

haddock-interfaces:   /usr/share/doc/haskell-gi/html/haskell-gi.haddock
haddock-html:         /usr/share/doc/haskell-gi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-0.26.8-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 haskell-gi
version:              0.26.8
visibility:           public
id:                   haskell-gi-0.26.8-77mKlYABuWk8ZUNoSu87ki
key:                  haskell-gi-0.26.8-77mKlYABuWk8ZUNoSu87ki
license:              LGPL-2.1-only
maintainer:           Iñaki García Etxebarria (github@the.blueleaf.cc)
author:               Will Thompson and Iñaki García Etxebarria
stability:            Experimental
homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    Generate Haskell bindings for GObject Introspection capable libraries

description:
    Generate Haskell bindings for GObject Introspection capable libraries. This includes most notably
    Gtk+, but many other libraries in the GObject ecosystem provide introspection data too.

category:             Development
abi:                  e6a1fdd44791c052b7edc3e02b4e638c
exposed:              True
exposed-modules:
    Data.GI.CodeGen.API Data.GI.CodeGen.Cabal
    Data.GI.CodeGen.CabalHooks Data.GI.CodeGen.Callable
    Data.GI.CodeGen.Code Data.GI.CodeGen.CodeGen Data.GI.CodeGen.Config
    Data.GI.CodeGen.Constant Data.GI.CodeGen.Conversions
    Data.GI.CodeGen.CtoHaskellMap Data.GI.CodeGen.EnumFlags
    Data.GI.CodeGen.Fixups Data.GI.CodeGen.GObject
    Data.GI.CodeGen.GType Data.GI.CodeGen.GtkDoc
    Data.GI.CodeGen.Haddock Data.GI.CodeGen.Inheritance
    Data.GI.CodeGen.LibGIRepository Data.GI.CodeGen.ModulePath
    Data.GI.CodeGen.OverloadedMethods Data.GI.CodeGen.OverloadedSignals
    Data.GI.CodeGen.Overrides Data.GI.CodeGen.PkgConfig
    Data.GI.CodeGen.ProjectInfo Data.GI.CodeGen.Properties
    Data.GI.CodeGen.Signal Data.GI.CodeGen.Struct
    Data.GI.CodeGen.SymbolNaming Data.GI.CodeGen.Transfer
    Data.GI.CodeGen.Type Data.GI.CodeGen.Util Data.GI.GIR.Alias
    Data.GI.GIR.Allocation Data.GI.GIR.Arg Data.GI.GIR.BasicTypes
    Data.GI.GIR.Callable Data.GI.GIR.Callback Data.GI.GIR.Constant
    Data.GI.GIR.Deprecation Data.GI.GIR.Documentation Data.GI.GIR.Enum
    Data.GI.GIR.Field Data.GI.GIR.Flags Data.GI.GIR.Function
    Data.GI.GIR.Interface Data.GI.GIR.Method Data.GI.GIR.Object
    Data.GI.GIR.Parser Data.GI.GIR.Property Data.GI.GIR.Repository
    Data.GI.GIR.Signal Data.GI.GIR.Struct Data.GI.GIR.Type
    Data.GI.GIR.Union Data.GI.GIR.XMLUtils

hidden-modules:       Paths_haskell_gi
import-dirs:          /usr/lib/ghc-9.2.8/site-local/haskell-gi-0.26.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/haskell-gi-0.26.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi
hs-libraries:         HShaskell-gi-0.26.8-77mKlYABuWk8ZUNoSu87ki
extra-libraries:      girepository-1.0 glib-2.0 gobject-2.0
include-dirs:
    /usr/include/gobject-introspection-1.0 /usr/include/glib-2.0
    /usr/lib/glib-2.0/include /usr/include/sysprof-6

depends:
    Cabal-3.6.3.0 ansi-terminal-0.11.5-GmxlGl1eC6rGTjWL8Yprft
    attoparsec-0.14.4-IUoeEKVn7Gr6GqDDI9lyTI base-4.16.4.0
    bytestring-0.11.4.0 containers-0.6.5.1 directory-1.3.6.2
    filepath-1.4.2.2 haskell-gi-base-0.26.5-9u86NL3wgSOEr4gB6yMmBl
    mtl-2.2.2 pretty-show-1.10-JwphvxEdk99BsHrT870tUy process-1.6.16.0
    regex-tdfa-1.3.2.2-743XGAHrGLPIAyhrr2nNbU
    safe-0.3.21-41ZPWazUMNgR08x0DBIts text-1.2.5.0 transformers-0.5.6.2
    xdg-basedir-0.2.2-BAENMrhgj9o4xkjbLJyx83
    xml-conduit-1.9.1.3-GY3EuCjZuJf7uAN9wBV66B

haddock-interfaces:   /usr/share/doc/haskell-gi/html/haskell-gi.haddock
haddock-html:         /usr/share/doc/haskell-gi/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
